animatorystates — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# animatorystates

The animatory state IDs recognised by Pyskool. They are used in the [SpriteGroup ...] sections of the ini file.

`animatorystates.` `ARM_UP` = 'ARM_UP'

  Character with arm raised (as if writing on a blackboard or opening a door).

`animatorystates.` `BENDING_OVER` = 'BENDING_OVER'

  Character bending over (as if to catch a mouse).

`animatorystates.` `BIKE_ON_FLOOR` = 'BIKE_ON_FLOOR'

  The bike lying on the floor.

`animatorystates.` `BIKE_UPRIGHT` = 'BIKE_UPRIGHT'

  The bike upright.

`animatorystates.` `CATAPULT0` = 'CATAPULT0'

  Character firing a catapult (phase 1).

`animatorystates.` `CATAPULT1` = 'CATAPULT1'

  Character firing a catapult (phase 2).

`animatorystates.` `CONKER` = 'CONKER'

  Conker.

`animatorystates.` `DESK_EMPTY` = 'DESK_EMPTY'

  Desk lid and empty desk.

`animatorystates.` `DESK_STINKBOMBS` = 'DESK_STINKBOMBS'

  Desk lid and stinkbombs.

`animatorystates.` `DESK_WATER_PISTOL` = 'DESK_WATER_PISTOL'

  Desk lid and water pistol.

`animatorystates.` `FLY` = 'FLY'

  Catapult pellet.

`animatorystates.` `HITTING0` = 'HITTING0'

  Character throwing a punch (phase 1).

`animatorystates.` `HITTING1` = 'HITTING1'

  Character throwing a punch (phase 2).

`animatorystates.` `HOP1` = 'HOP1'

  Frog hopping (phase 1).

`animatorystates.` `HOP2` = 'HOP2'

  Frog hopping (phase 2).

`animatorystates.` `KISSING_ERIC` = 'KISSING_ERIC'

  Character kissing Eric.

`animatorystates.` `KNOCKED_OUT` = 'KNOCKED_OUT'

  Character lying on back (as if knocked out).

`animatorystates.` `KNOCKED_OVER` = 'KNOCKED_OVER'

  Character sitting on the floor (as when hit by a catapult pellet).

`animatorystates.` `PLANT_GROWING` = 'PLANT_GROWING'

  Plant half-grown.

`animatorystates.` `PLANT_GROWN` = 'PLANT_GROWN'

  Plant fully grown.

`animatorystates.` `RIDING_BIKE0` = 'RIDING_BIKE0'

  Character riding a bike (phase 1).

`animatorystates.` `RIDING_BIKE1` = 'RIDING_BIKE1'

  Character riding a bike (phase 2).

`animatorystates.` `RUN` = 'RUN'

  Mouse running.

`animatorystates.` `SHERRY_DROP` = 'SHERRY_DROP'

  Drop of sherry (spilt from a cup).

`animatorystates.` `SIT` = 'SIT'

  Frog sitting still.

`animatorystates.` `SITTING_ON_CHAIR` = 'SITTING_ON_CHAIR'

  Character sitting on a chair.

`animatorystates.` `SITTING_ON_FLOOR` = 'SITTING_ON_FLOOR'

  Character sitting on the floor (as for assembly).

`animatorystates.` `STINKBOMB` = 'STINKBOMB'

  Stinkbomb cloud.

`animatorystates.` `WALK0` = 'WALK0'

  Character standing/walking (phase 1).

`animatorystates.` `WALK1` = 'WALK1'

  Character standing/walking (phase 2).

`animatorystates.` `WALK2` = 'WALK2'

  Character standing/walking (phase 3).

`animatorystates.` `WALK3` = 'WALK3'

  Character standing/walking (phase 4).

`animatorystates.` `WATER0` = 'WATER0'

  Water fired from a water pistol (phase 1).

`animatorystates.` `WATER1` = 'WATER1'

  Water fired from a water pistol (phase 2).

`animatorystates.` `WATER2` = 'WATER2'

  Water fired from a water pistol (phase 3).

`animatorystates.` `WATER3` = 'WATER3'

  Water fired from a water pistol (phase 4).

`animatorystates.` `WATER4` = 'WATER4'

  Water fired from a water pistol (phase 5+).

`animatorystates.` `WATERPISTOL` = 'WATERPISTOL'

  Character firing a water pistol.

`animatorystates.` `WATER_DROP` = 'WATER_DROP'

  Drop of water (spilt from a cup).

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »